---
title: 토스페이먼츠 현금영수증 옵션을 제어할 수 있나요?
category: 자주 묻는 질문 (일반 문의) > 결제서비스 > 결제서비스
seo:
  title: 토스페이먼츠 현금영수증 노출제어방법
  description: >-
    토스페이먼츠의 현금영수증 발행화면 제어 방법 안내입니다. 토스페이먼츠를 통해 현금영수증을 발행하시는 경우 결제수단별로 토스페이먼츠 결제창
    내 현금영수증 발행여부의 노출여부를 제어할 수 있습니다.
  keywords:
    - 현금영수증
tags:
  - 토스페이먼츠
  - 현금영수증
pgCompanies:
  - 토스페이먼츠
searchTags:
  - 현금영수증 노출
  - 토스페이먼츠 현금영수증
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="토스페이먼츠의 현금영수증 발행화면을 제어할 수 있는 방법을 안내드립니다." />

### **토스페이먼츠 결제창 내 현금영수증 노출 제어**

토스페이먼츠를 통해 현금영수증을 발행하시는 경우 결제수단별로 토스페이먼츠 결제창 내 ‘현금영수증 발행여부’ 노출여부를 제어할 수 있습니다.

- 경로 : [토스페이먼츠 상점관리자페이지↗](https://app.tosspayments.com/) > 상점정보관리 > MID 검색 > 결제수단 관리에서 각 지불수단 선택 후 현금영수증 사용여부 확인

현금영수증은 발행 유형과 관련하여 보다 자세한 안내는 아래에서 확인하실 수 있습니다.

<Callout title="현금영수증 발행방법 보러가기↗" icon="" />
